package com.ynet.life.i18n;

import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.io.File;
import java.util.HashMap;
import java.util.Map;
import javax.xml.parsers.DocumentBuilderFactory;
import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

/* loaded from: com_ynet_life_i18n.jar:com/ynet/life/i18n/ResourceXMLReader.class */
public class ResourceXMLReader {
    private static final String XML_TAG_NAME_RESOURCE_VALUE = "resourceValue";
    private static final String XML_TAG_NAME_ID = "id";
    private Node itsRootNode;

    public ResourceXMLReader(String fileName) {
        try {
            DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
            factory.setValidating(false);
            Document doc = factory.newDocumentBuilder().parse(new File(fileName));
            this.itsRootNode = doc.getFirstChild();
        } catch (Exception ex) {
            Trace.logError("LifeXML", "资源文件读取异常", ex);
        }
    }

    public Map getResoures() throws TranFailException {
        Node temp;
        Map result = new HashMap();
        NodeList resources = this.itsRootNode.getChildNodes().item(1).getChildNodes();
        int size = resources.getLength();
        for (int i = 0; i < size; i++) {
            Node node = resources.item(i);
            if (node.getNodeType() == 1 && (temp = node.getAttributes().getNamedItem(XML_TAG_NAME_ID)) != null) {
                String resourceID = temp.getNodeValue();
                if (result.containsKey(resourceID)) {
                    Trace.logError("LifeCore", "资源定义[" + resourceID + "]重复");
                }
                Resource newResource = new Resource(resourceID);
                NodeList languageNodes = node.getChildNodes();
                int languageNodeSize = languageNodes.getLength();
                for (int j = 0; j < languageNodeSize; j++) {
                    Node child = languageNodes.item(j);
                    if (child.getNodeType() == 1 && child.getNodeName().equals(XML_TAG_NAME_RESOURCE_VALUE)) {
                        addResourceLanguage(newResource, child);
                    }
                }
                result.put(resourceID, newResource);
            }
        }
        return result;
    }

    private void addResourceLanguage(Resource resource, Node languageNode) throws TranFailException {
        String value;
        Node temp = languageNode.getAttributes().getNamedItem(XML_TAG_NAME_ID);
        if (temp != null) {
            String language = temp.getNodeValue();
            try {
                value = languageNode.getFirstChild().getNodeValue();
            } catch (Exception unused) {
                value = "";
            }
            resource.addLanguage(language, value);
        }
    }
}
